<?php
/**
 * @version    4.0.0
 * @package    Com_AllVideoShare
 * @author     Vinoth Kumar <admin@mrvinoth.com>
 * @copyright  Copyright (c) 2012 - 2021 Vinoth Kumar. All Rights Reserved.
 * @license    GNU General Public License version 2 or later; see LICENSE.txt
 */

// No direct access
defined( '_JEXEC' ) or die;

use Joomla\CMS\Factory;
use Joomla\CMS\HTML\HTMLHelper;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Router\Route;
use Joomla\CMS\Uri\Uri;
use MrVinoth\Component\AllVideoShare\Site\Helper\AllVideoShareHelper;

HTMLHelper::addIncludePath( JPATH_COMPONENT . '/helpers/html' );
HTMLHelper::_( 'bootstrap.tooltip' );

$wa = $this->document->getWebAssetManager();
$wa->useScript( 'keepalive' )
	->useScript( 'form.validate' );
?>

<form action="<?php echo Route::_( 'index.php?option=com_allvideoshare&layout=edit&id=' . (int) $this->item->id ); ?>" method="post" enctype="multipart/form-data" name="adminForm" id="player-form" class="form-validate form-horizontal">
	<?php echo HTMLHelper::_( 'uitab.startTabSet', 'myTab', array( 'active' => 'general' ) ); ?>

	<?php echo HTMLHelper::_( 'uitab.addTab', 'myTab', 'general', Text::_( 'COM_ALLVIDEOSHARE_TAB_GENERAL', true ) ); ?>
		<div class="row-fluid">
			<div class="span10 form-horizontal">
				<fieldset class="options-form">
					<legend><?php echo Text::_( 'COM_ALLVIDEOSHARE_FIELDSET_GENERAL' ); ?></legend>
					<?php echo $this->form->renderField( 'name' ); ?>
					<?php echo $this->form->renderField( 'ratio' ); ?>
					<?php echo $this->form->renderField( 'loop' ); ?>
					<?php echo $this->form->renderField( 'autostart' ); ?>
					<?php echo $this->form->renderField( 'volumelevel' ); ?>
					<?php echo $this->form->renderField( 'state' ); ?>
				</fieldset>
			</div>
		</div>
	<?php echo HTMLHelper::_( 'uitab.endTab' ); ?>

	<?php echo HTMLHelper::_( 'uitab.addTab', 'myTab', 'playercontrols', Text::_( 'COM_ALLVIDEOSHARE_TAB_PLAYERCONTROLS', true ) ); ?>
		<div class="row-fluid">
			<div class="span10 form-horizontal">
				<fieldset class="options-form">
					<legend><?php echo Text::_( 'COM_ALLVIDEOSHARE_FIELDSET_PLAYERCONTROLS' ); ?></legend>
					<?php echo $this->form->renderField( 'controlbar' ); ?>
					<?php echo $this->form->renderField( 'durationdock' ); ?>
					<?php echo $this->form->renderField( 'timerdock' ); ?>
					<?php echo $this->form->renderField( 'fullscreendock' ); ?>
					<?php echo $this->form->renderField( 'hddock' ); ?>

					<?php 
					if ( AllVideoShareHelper::canDo() ) {
						echo $this->form->renderField( 'embeddock' );
					} else {
						echo '<div class="control-group">';
						echo '<div class="control-label">' . $this->form->getLabel( 'embeddock' ) . '</div>';
						echo '<div class="controls">';
						echo '<span class="form-text text-danger">' . Text::_( 'COM_ALLVIDEOSHARE_PREMIUM_LBL_PRO_ONLY' ) . '</span>';
						echo '<input type="hidden" name="jform[embeddock]" value="0" />';
						echo '</div>';
						echo '</div>';
					}
					?>

					<?php 
					if ( AllVideoShareHelper::canDo() ) {
						echo $this->form->renderField( 'sharedock' );
					} else {
						echo '<div class="control-group">';
						echo '<div class="control-label">' . $this->form->getLabel( 'sharedock' ) . '</div>';
						echo '<div class="controls">';
						echo '<span class="form-text text-danger">' . Text::_( 'COM_ALLVIDEOSHARE_PREMIUM_LBL_PRO_ONLY' ) . '</span>';
						echo '<input type="hidden" name="jform[sharedock]" value="0" />';
						echo '</div>';
						echo '</div>';
					}
					?>
				</fieldset>
			</div>
		</div>
	<?php echo HTMLHelper::_('uitab.endTab'); ?>

	<?php echo HTMLHelper::_( 'uitab.addTab', 'myTab', 'advertisements', Text::_( 'COM_ALLVIDEOSHARE_TAB_ADVERTISEMENTS', true ) ); ?>
		<div class="row-fluid">
			<div class="span10 form-horizontal">
				<fieldset class="options-form">
					<legend><?php echo Text::_( 'COM_ALLVIDEOSHARE_FIELDSET_ADVERTISEMENTS' ); ?></legend>
					<?php 
					if ( AllVideoShareHelper::canDo() ) {
						echo $this->form->renderField( 'ad_engine' );
						echo $this->form->renderField( 'preroll' );
						echo $this->form->renderField( 'postroll' ); 
						echo $this->form->renderField( 'vast_url' );
					} else {
						echo '<div class="control-group">';
						echo '<div class="control-label">' . $this->form->getLabel( 'ad_engine' ) . '</div>';
						echo '<div class="controls">';
						echo '<span class="form-text text-danger">' . Text::_( 'COM_ALLVIDEOSHARE_PREMIUM_DESC_AD_TYPE' ) . '</span>';
						echo '<input type="hidden" name="jform[ad_engine]" value="custom" />';
						echo '</div>';
						echo '</div>';

						echo '<div class="control-group">';
						echo '<div class="control-label">' . $this->form->getLabel( 'preroll' ) . '</div>';
						echo '<div class="controls">' . $this->form->getInput( 'preroll' ) . '</div>';
						echo '</div>';

						echo '<div class="control-group">';
						echo '<div class="control-label">' . $this->form->getLabel( 'postroll' ) . '</div>';
						echo '<div class="controls">' . $this->form->getInput( 'postroll' ) . '</div>';
						echo '</div>';
					}
					?>
				</fieldset>
			</div>
		</div>
	<?php echo HTMLHelper::_( 'uitab.endTab' ); ?>

	<input type="hidden" name="jform[id]" value="<?php echo $this->item->id; ?>" />
	<input type="hidden" name="jform[ordering]" value="<?php echo $this->item->ordering; ?>" />
	<input type="hidden" name="jform[checked_out]" value="<?php echo $this->item->checked_out; ?>" />
	<input type="hidden" name="jform[checked_out_time]" value="<?php echo $this->item->checked_out_time; ?>" />
	<?php echo $this->form->renderField( 'created_by' ); ?>
	<?php echo $this->form->renderField( 'modified_by' ); ?>
	
	<?php echo HTMLHelper::_( 'uitab.endTabSet' ); ?>

	<input type="hidden" name="task" value="" />
	<?php echo HTMLHelper::_( 'form.token' ); ?>
</form>
