(function( $ ) {
	'use strict';

	/**
	 * Initialize the slick slider
	 *
	 * @since  4.0.0
	 */
	 function avs_init_slick( $this ) {
		$this.addClass( 'avs-slick-initialized' );

		var params = $this.data( 'params' );			
		var arrow_styles = 'top: ' + params.arrow_top_offset + '; width: ' + params.arrow_size  + '; height: ' + params.arrow_size + '; background: ' + params.arrow_bg_color + '; border-radius: ' + params.arrow_radius + '; font-size: ' + params.arrow_icon_size + '; color: ' + params.arrow_icon_color + '; line-height: ' + params.arrow_size + ';';
		
		// Slick			
		var $carousel = $this.slick({
			rtl: ( parseInt( params.is_rtl ) ? true : false ),
			prevArrow: '<div class="avs-slick-prev" style="left: ' + params.arrow_left_offset + '; ' + arrow_styles + '" role="button">&#10094;</div>',
			nextArrow: '<div class="avs-slick-next" style="right: ' + params.arrow_right_offset + '; ' + arrow_styles + '" role="button">&#10095;</div>',
			dotsClass: 'avs-slick-dots',
			customPaging: function( slider, i ) {					
				return '<div class="avs-slick-dot" style="color: ' + params.dot_color + '; font-size: ' + params.dot_size + '" role="button">&#9679;</div>';
			}
		});

		// Popup
		if ( $this.hasClass( 'avs-slick-popup' ) ) {
			var player_ratio = parseFloat( $( this ).data( 'player_ratio' ) );

			$carousel.magnificPopup({ 
				delegate: '.slick-slide:not(.slick-cloned) .avs-grid-item', // the selector for gallery item
				type: 'iframe',
				overflowY: 'auto',			
				removalDelay: 300,
				iframe: { // to create title, close, iframe, counter div's
				markup: '<div class="mfp-title-bar">' +
							'<div class="mfp-close" title="Close (Esc)"></div>' +
						'</div>' +							
						'<div class="mfp-iframe-scaler" style="padding-top:' + player_ratio + '%;" >' +            												
							'<iframe class="mfp-iframe" frameborder="0" allowfullscreen></iframe>' +																								
						'</div>'																							        			
				},	
				gallery: { // to build gallery				
					enabled: true													
				}									
			});	
		}
	}

	/**
	 * Called when the page has loaded
	 *
	 * @since  4.0.0
	 */
	$(function() {
		// Magnific Popup 
		if ( $.fn.magnificPopup !== undefined ) {
			$( '.avs-popup' ).each(function() {	
				var player_ratio = parseFloat( $( this ).data( 'player_ratio' ) );

				$( this ).magnificPopup({ 
					delegate: '.avs-grid-item', // the selector for gallery item
					type: 'iframe',
					overflowY: 'auto',			
					removalDelay: 300,
					iframe: { // to create title, close, iframe, counter div's
					markup: '<div class="mfp-title-bar">' +
								'<div class="mfp-close" title="Close (Esc)"></div>' +
							'</div>' +							
							'<div class="mfp-iframe-scaler" style="padding-top:' + player_ratio + '%;" >' +            												
								'<iframe class="mfp-iframe" frameborder="0" allowfullscreen></iframe>' +																								
							'</div>'																							        			
					},	
					gallery: { // to build gallery				
						enabled: true													
					}									
				});	
			});
		};

		// Slider
		if ( $.fn.slick !== undefined ) {
			// Initialize the Slider
			$( '.avs-slick' ).each(function() {	
				var $this = $( this );					
				avs_init_slick( $this );
				
				// On before slide change
				var type = $this.data( 'type' );
				
				if ( 'player' == type ) {				
					$this.on( 'beforeChange', function( event, slick, current_slide, next_slide ) {								   
						$this.find( '.avs-player' ).html( '' );
						
						var $next_slide = $( slick.$slides[ next_slide ] );
						var src = $next_slide.find( '.avs-player' ).data( 'src' );
						$next_slide.find( '.avs-player' ).html( '<iframe src="' + src + '" frameborder="0" allow="accelerometer; autoplay; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe>' );					
					});				
				}										   
			});	
		};	

		// GDPR Privacy Consent
		$( '.avs-gdpr-consent-button' ).on( 'click', function() {	
			var $this = $( this );
			$this.html( '...' );

			// Set Cookie
			var xmlhttp;

			if ( window.XMLHttpRequest ) {
				xmlhttp = new XMLHttpRequest();
			} else {
				xmlhttp = new ActiveXObject( 'Microsoft.XMLHTTP' );
			};
			
			xmlhttp.onreadystatechange = function() {                
				if ( 4 == xmlhttp.readyState && 200 == xmlhttp.status ) {                    
					if ( 'success' == xmlhttp.responseText ) {
						var container = $this.closest( '.avs-player' );
			
						var iframe = container.find( 'iframe' ).clone();
						var src = iframe.data( 'src' );
						iframe.attr( 'src', src );
						
						container.html( iframe );	
					}                        
				}                    
			};	

			xmlhttp.open( 'GET', $( this ).data( 'baseurl' ) + 'index.php?option=com_allvideoshare&task=player.cookie', true );
			xmlhttp.send();	
		});			
	});

})( jQuery );