<?php
/**
 * @version     4.0.0
 * @package     Com_AllVideoShare
 * @subpackage  Mod_AllVideoShareCarousel
 * @author      Vinoth Kumar <admin@mrvinoth.com>
 * @copyright   Copyright (c) 2012 - 2021 Vinoth Kumar. All Rights Reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 */

namespace MrVinoth\Module\AllVideoShareCarousel\Site\Helper;

\defined( '_JEXEC' ) or die;

use \Joomla\CMS\Factory;
use \Joomla\CMS\Language\Language;
use \Joomla\CMS\Language\Text;
use \Joomla\CMS\Uri\Uri;
use \MrVinoth\Component\AllVideoShare\Site\Helper\AllVideoShareHelper;
use \MrVinoth\Component\AllVideoShare\Site\Helper\AllVideoShareQuery;

/**
 * Helper for mod_allvideosharecarousel
 *
 * @since  4.0.0
 */
Class AllVideoShareCarouselHelper {

	/**
	 * Retrieve videos
	 *
	 * @param   Joomla\Registry\Registry  &$params  Module parameters
	 *
	 * @return  array  The videos list.
	 * 
	 * @since   4.0.0
	 */
	public static function getItems( &$params ) {	
		$db = Factory::getDbo();

		$query = 'SELECT * FROM #__allvideoshare_videos WHERE state=1';
		
		$catid = AllVideoShareQuery::getCategoryIdByAlias( $params->get( 'category' ) );
		if ( $catid ) {
			$query .= ' AND ( catid=' . $catid .' OR catids LIKE ' . $db->Quote( '% ' . $catid . ' %' ) . ' )';
		}
		
		$alias = AllVideoShareHelper::getAlias();
		if ( ! empty( $alias ) ) {
			$query .= ' AND slug != ' . $db->Quote( $alias );
		}
		
		if ( 'featured' == $params->get( 'orderby' ) || 1 == $params->get( 'featured', 0 ) ) {
			$query .= ' AND featured=1';
		}
		
		switch ( $params->get( 'orderby' ) ) {
			case 'ordering':
				$query .= ' ORDER BY ordering ASC';
				break;
			case 'latest':
				$query .= ' ORDER BY id DESC';
				break;
			case 'popular':
				$query .= ' ORDER BY views DESC';
				break;
			case 'random':
				$query .= ' ORDER BY RAND()';
				break;
			default:
				$query .= ' ORDER BY created_date DESC';
		}			
		
		$limit = (int) $params->get( 'limit' );
		
		$db->setQuery( $query, 0, $limit );
       	$items = $db->loadObjectList();
			
        return $items;		
    }
	
}
