<?php
/**
 * @version     4.0.0
 * @package     Com_AllVideoShare
 * @subpackage  Mod_AllVideoShareGallery
 * @author      Vinoth Kumar <admin@mrvinoth.com>
 * @copyright   Copyright (c) 2012 - 2021 Vinoth Kumar. All Rights Reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 */

defined( '_JEXEC' ) or die;

use Joomla\CMS\Factory;
use Joomla\CMS\Router\Route;
use Joomla\CMS\Language\Text;
use MrVinoth\Component\AllVideoShare\Site\Helper\AllVideoShareHelper;
use MrVinoth\Component\AllVideoShare\Site\Helper\AllVideoShareRoute;
use MrVinoth\Module\AllVideoShareGallery\Site\Helper\AllVideoShareGalleryHelper;

$items = AllVideoShareGalleryHelper::getCategories( $params );

// Vars
$columns = (int) $params->get( 'cols', 3 );
$column = 0;
$column_no = floor( 12 / $columns );

$column_class = 'col-sm-' . $column_no;

$image_ratio = (float) $params->get( 'image_ratio', 56.25 );

$custom_route = $params->get( 'link' );
if ( ! empty( $custom_route ) ) {
	$custom_route  = str_replace( 'slg=', '', $custom_route );
	$custom_route .= ! strpos( $custom_route, '?' ) ? '?slg=' : '&slg=';
}

$show_more = 0;
if ( $params->get( 'more' ) ) {
	$total = AllVideoShareGalleryHelper::getTotalCategories( $params );

	if ( $total > count( $items ) ) {
		$show_more = 1;
	}
}

// Import CSS
$wa = $app->getDocument()->getWebAssetManager();

if ( ! $wa->assetExists( 'style', 'com_allvideoshare.site' ) ) {
	$wr = $wa->getRegistry();
	$wr->addRegistryFile( 'media/com_allvideoshare/joomla.asset.json' );
}

$wa->useStyle( 'com_allvideoshare.site' );

if ( $css = $params->get( 'custom_css' ) ) {
    $wa = $app->getDocument()->getWebAssetManager();
    $wa->addInlineStyle( $css );
}
?>

<div class="avs mod_allvideosharegallery categories">
	<?php if ( empty( $items ) ) : ?>
		<p class="text-muted">
			<?php echo Text::_( 'MOD_ALLVIDEOSHAREGALLERY_NO_ITEMS_FOUND' ); ?>
		</p>
	<?php else : ?>
		<div class="avs-grid">
			<div class="row">
				<?php foreach ( $items as $i => $item ) : 
					if ( $column >= $columns ) {
						echo '</div><div class="row">';
						$column = 0;
					}

					if ( ! empty( $custom_route ) ) {
						$route = $custom_route . $item->slug;
					} else {
						$route = AllVideoShareRoute::getCategoryRoute( $item->slug );
					}
					$item_link = Route::_( $route );
					?>
					<div class="<?php echo $column_class; ?>">
						<div class="card mb-3">
							<a href="<?php echo $item_link; ?>" class="avs-responsive-item" style="padding-bottom: <?php echo $image_ratio; ?>%">
								<div class="avs-image" style="background-image: url( '<?php echo AllVideoShareHelper::getImage( $item ); ?>' );">&nbsp;</div>
							</a>

							<div class="card-body">
								<a href="<?php echo $item_link; ?>" class="card-link"><?php echo $item->name; ?></a>
							</div>					
						</div>
					</div>
					<?php
					if ( $column >= $columns ) echo '</div>';
					$column++;
				endforeach; ?>
			</div>

			<?php if ( $show_more ) : ?>
				<a class="btn btn-primary" href="<?php echo AllVideoShareRoute::getRoute( 0, 'category' ); ?>">
					<?php echo Text::_( 'MOD_ALLVIDEOSHAREGALLERY_SHOW_MORE_BUTTON_LABEL' ); ?>
				</a>
			<?php endif; ?>
		</div>		
	<?php endif; ?>
</div>
