<?php
/**
 * @version    4.0.0
 * @package    Com_AllVideoShare
 * @author     Vinoth Kumar <admin@mrvinoth.com>
 * @copyright  Copyright (c) 2012 - 2021 Vinoth Kumar. All Rights Reserved.
 * @license    GNU General Public License version 2 or later; see LICENSE.txt
 */

namespace MrVinoth\Component\AllVideoShare\Site\Helper;

\defined( '_JEXEC' ) or die;

use \Joomla\CMS\Factory;
use \Joomla\CMS\Language\Text;
use \Joomla\CMS\MVC\Model\BaseDatabaseModel;
use \Joomla\CMS\Session\Session;
use \Joomla\CMS\Uri\Uri;
use \MrVinoth\Component\AllVideoShare\Site\Helper\AllVideoShareQuery;

/**
 * Class AllVideoSharePlayer
 *
 * @since  4.0.0
 */
class AllVideoSharePlayer {	

	/**
	 * Gets the player HTML
	 *
	 * @param   array  $input  The player configuration parameters.
	 *
	 * @return  string
	 * 
	 * @since   4.0.0
	 */
	public static function load( $input = array() ) {
		$html = '';

		if ( ! empty( $input['videoid'] ) ) {
			$app = Factory::getApplication();

			// Import CSS
			$wa = $app->getDocument()->getWebAssetManager();

			if ( ! $wa->assetExists( 'style', 'com_allvideoshare.site' ) ) {
				$wr = $wa->getRegistry();
				$wr->addRegistryFile( 'media/com_allvideoshare/joomla.asset.json' );
			}

			$wa->useStyle( 'com_allvideoshare.site' );

			// Load component language file
			$lang = Factory::getLanguage();
			$lang->load( 'com_allvideoshare', JPATH_SITE );

			// Get Item
			$video = AllVideoShareQuery::getVideo( $input['videoid'] );

			// Build Player HTML
			if ( ! empty( $video ) ) {
				// Get player settings
				$player = AllVideoShareQuery::getPlayer( $input['playerid'] );

				// Get Params
				$params = $app->getParams( 'com_allvideoshare' );
				
				// Build the player HTML
				if ( 'thirdparty' == $video->type ) {
					if ( $params->get( 'show_gdpr_consent' ) && $app->input->cookie->get( 'com_allvideoshare_gdpr', null ) == null ) {
						$wa->useScript( 'com_allvideoshare.site' );

						$html  = '<div class="avs-player" style="padding-bottom: ' . (float) $player->ratio . '%;">'; 
						$html .= str_replace( ' src=', ' data-src=', $video->thirdparty );  
						$html .= sprintf( 
							'<div class="avs-gdpr-wrapper" style="background-image: url(%s);">', 
							$video->thumb 
						);
						$html .= '<div class="avs-gdpr-consent-block">';
						$html .= sprintf( 
							'<div class="avs-gdpr-consent-message">%s</div>', 
							Text::_( 'COM_ALLVIDEOSHARE_PLAYER_GDPR_CONSENT_MESSAGE' ) 
						);
						$html .= sprintf( 
							'<div class="avs-gdpr-consent-button" data-baseurl="%s">%s</div>', 
							URI::root(), 
							Text::_( 'COM_ALLVIDEOSHARE_PLAYER_GDPR_CONSENT_BUTTON_LABEL' ) 
						);
						$html .= '</div>';
						$html .= '</div>'; 
						$html .= '</div>';          
					} else {
						$html = sprintf( 
							'<div class="avs-player" style="padding-bottom: %s;">%s</div>', 
							(float) $player->ratio . '%', 
							$video->thirdparty
						);

						self::updateViews( $video->id );
					}
				} else {
					$html = sprintf( 
						'<div class="avs-player" style="padding-bottom: %s;"><iframe width="560" height="315" src="%s" frameborder="0" allow="accelerometer; autoplay; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe></div>', 
						(float) $player->ratio . '%', 
						Uri::root() . 'index.php?option=com_allvideoshare&view=player&format=raw&vid=' . (int) $video->id . '&pid=' . (int) $player->id
					);
				}
			}
		}

		return $html;
	}

	/**
	 * Update views count
	 *
	 * @param   int  $id  The video id.
	 * 
	 * @since   4.0.0
	 */
	public static function updateViews( $id ) {		
		$session = Factory::getSession();
		
		$stored = array();		
		if ( $session->get( 'com_allvideoshare_views' ) ) {
			$stored = $session->get( 'com_allvideoshare_views' );
		}
		
		if ( ! in_array( $id, $stored ) ) {
		    $stored[] = $id;				
	 
			$db = Factory::getDbo();
		 	$query = 'UPDATE #__allvideoshare_videos SET views=views+1 WHERE id=' . (int) $id;
    	 	$db->setQuery( $query );
		 	$db->execute();
		 
		 	$session->set( 'com_allvideoshare_views', $stored );
		}		
	}

	/**
	 * Set GDPR cookie
	 * 
	 * @since   4.0.0
	 */
	public static function setCookie() {
        $app = Factory::getApplication();

        // Set the cookie
        $time = time() + 604800; // 1 week
        $app->input->cookie->set( 'com_allvideoshare_gdpr', 1, $time, $app->get( 'cookie_path', '/' ), $app->get( 'cookie_domain' ), $app->isSSLConnection() );
    }
	
}
