<?php
/**
 * @version     4.0.0
 * @package     Com_AllVideoShare
 * @author      Vinoth Kumar <admin@mrvinoth.com>
 * @copyright   Copyright (c) 2012 - 2021 Vinoth Kumar. All Rights Reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 */

namespace MrVinoth\Component\AllVideoShare\Site\Helper;

\defined( '_JEXEC' ) or die;

use \Joomla\CMS\Component\ComponentHelper;
use \Joomla\CMS\Factory;
use \Joomla\CMS\Language\Multilanguage;
use \Joomla\CMS\Router\Route;

/**
 * Class AllVideoShareRoute.
 *
 * @since  4.0.0
 */
abstract class AllVideoShareRoute {

	/**
	 * Get the URL route for a category
	 *
	 * @param   integer  $alias     The category slug.
	 * @param   integer  $menuId    The id of the menu item.
	 * @param   mixed    $language  The id of the language being used.
	 *
	 * @return  string   The link to the category
	 *
	 * @since   4.0.0
	 */
	public static function getCategoryRoute( $alias, $menuId = 0, $language = 0 ) {
		// Create the link
		$link = 'index.php?option=com_allvideoshare&view=category&slg=' . $alias;

		if ( $menuId > 1 ) {
			$link .= '&Itemid=' . (int) $menuId;
		}

		if ( $language && $language !== '*' && Multilanguage::isEnabled() ) {
			$link .= '&lang=' . $language;
		}

		return $link;
	}

	/**
	 * Get the URL route for a video
	 *
	 * @param   integer  $alias     The video slug.
	 * @param   integer  $menuId    The id of the menu item.
	 * @param   mixed    $language  The id of the language being used.
	 *
	 * @return  string   The link to the video
	 *
	 * @since   4.0.0
	 */
	public static function getVideoRoute( $alias, $menuId = 0, $language = 0 ) {
		// Create the link
		$link = 'index.php?option=com_allvideoshare&view=video&slg=' . $alias;

		if ( empty( $menuId ) ) {
			$params = ComponentHelper::getParams( 'com_allvideoshare' );
			$menuId = (int) $params->get( 'itemid_video' );
		}

		if ( $menuId > 1 ) {
			$link .= '&Itemid=' . (int) $menuId;
		}

		if ( $language && $language !== '*' && Multilanguage::isEnabled() ) {
			$link .= '&lang=' . $language;
		}

		return $link;
	}

	/**
	 * Get the URL route for a search
	 *
	 * @param   integer  $menuId    The id of the menu item.
	 * @param   mixed    $language  The id of the language being used.
	 *
	 * @return  string   The link to the search
	 *
	 * @since   4.0.0
	 */
	public static function getSearchRoute( $menuId = 0, $language = 0 ) {
		// Create the link
		$link = 'index.php?option=com_allvideoshare&view=search';

		if ( $menuId > 1 ) {
			$link .= '&Itemid=' . (int) $menuId;
		}

		if ( $language && $language !== '*' && Multilanguage::isEnabled() ) {
			$link .= '&lang=' . $language;
		}

		return $link;
	}

	public static function getRoute( $slug = 0, $view = 'video', $itemId = 0 ) {
		$is_exact_match_found = 0;
		
		// Check if there is a menu item with the given SLUG value for the view
		$itemId = self::findItem( $slug, $view );
		if ( $itemId > 0 ) {
			$is_exact_match_found = 1;
		}
		
		// Check if there is a menu item atleast for the view
		if ( empty( $itemId ) ) {
			$itemId = self::findItem( '%', $view );
		}
		
		// Fallback to the current itemId
		if ( empty( $itemId ) ) {
			$app = Factory::getApplication();
			$itemId = $app->input->getInt( 'Itemid', 0 );
		}

		// Build route
		if ( $is_exact_match_found ) {
			$route = "index.php?Itemid=$itemId";
		} else {
			$route = "index.php?option=com_allvideoshare&view=$view&slg=$slug";
			if ( $itemId > 0 ) {
				$route .= "&Itemid=$itemId";
			}
		}
		
		return Route::_( $route );	
	}

	protected static function findItem( $slug, $view, $itemId = 0 ) {	
		$db = Factory::getDbo();
		
		$query = 'SELECT id FROM #__menu';

		if ( '%' == $slug ) {
			$query .= " WHERE link LIKE " . $db->quote( "index.php?option=com_allvideoshare&view=$view&slg=$slug" );
		} else {
			$query .= " WHERE link=" . $db->quote( "index.php?option=com_allvideoshare&view=$view&slg=$slug" );
		}

		$query .= ' AND published=1 LIMIT 1';

		$db->setQuery( $query );
		if ( $id = $db->loadResult() ) {
			$itemId = $id;
		}
		
		return $itemId;
	}

}
