<?php
/**
 * @version    4.0.0
 * @package    Com_AllVideoShare
 * @author     Vinoth Kumar <admin@mrvinoth.com>
 * @copyright  Copyright (c) 2012 - 2021 Vinoth Kumar. All Rights Reserved.
 * @license    GNU General Public License version 2 or later; see LICENSE.txt
 */

namespace MrVinoth\Component\AllVideoShare\Site\View\Player;

// No direct access
\defined( '_JEXEC' ) or die;

use \Joomla\CMS\Factory;
use \Joomla\CMS\Language\Text;
use \Joomla\CMS\MVC\View\AbstractView;
use \Joomla\CMS\Router\Route;
use \Joomla\CMS\Uri\Uri;
use \Joomla\Component\Content\Site\Helper\RouteHelper;
use \MrVinoth\Component\AllVideoShare\Site\Helper\AllVideoShareHelper;
use \MrVinoth\Component\AllVideoShare\Site\Helper\AllVideoSharePlayer;
use \MrVinoth\Component\AllVideoShare\Site\Helper\AllVideoShareQuery;

/**
 * Frontpage View class
 *
 * @since  4.0.0
 */
class RawView extends AbstractView {

	protected $state;

	protected $item;	

	protected $params;

	protected $player;

	/**
	 * Display the view
	 *
	 * @param   string  $tpl  Template name
	 *
	 * @return  void
	 *
	 * @since   4.0.0
	 * @throws  Exception
	 */
	public function display( $tpl = null ) {
		$app = Factory::getApplication();

		$this->state = $this->get( 'State' );

		$this->item = $this->get( 'Item' ); 
		if ( empty( $this->item ) ) {
            return;
        }	

		$this->canDo  = AllVideoShareHelper::canDo(); 
		$this->params = AllVideoShareHelper::getParams();
		$this->player = AllVideoShareQuery::getPlayer(); 	       	

		// Fallback to old versions that doesn't have the youtube field
		if ( $this->item->type == 'youtube' ) {
			if ( empty( $this->item->youtube ) && ! empty( $this->item->video ) ) {
				if ( false !== strpos( $this->item->video, 'youtube.com' ) || false !== strpos( $this->item->video, 'youtu.be' ) ) {
					$this->item->youtube = $this->item->video;
				}
			}
		}

		// Fallback to old versions that doesn't have the vimeo field
		if ( $this->item->type == 'vimeo' ) {
			if ( empty( $this->item->vimeo ) && ! empty( $this->item->video ) ) {
				if ( false !== strpos( $this->item->video, 'vimeo.com' ) ) {
					$this->item->vimeo = $this->item->video;
				}
			}
		}

		if ( $this->params->get( 'show_gdpr_consent' ) && $app->input->cookie->get( 'com_allvideoshare_gdpr', null ) == null ) {
			if ( in_array( $this->item->type, array( 'youtube', 'vimeo', 'thirdparty' ) ) ) {
				require JPATH_ROOT . '/components/com_allvideoshare/tmpl/player/gdpr.php';
				return;
			}
		}

		if ( 'thirdparty' == $this->item->type ) {
			require JPATH_ROOT . '/components/com_allvideoshare/tmpl/player/iframe.php';
		} else {
			require JPATH_ROOT . '/components/com_allvideoshare/tmpl/player/html5.php';
		}	
		
		AllVideoSharePlayer::updateViews( $this->item->id );
	}

	public function getTitle() {	
		$app   = Factory::getApplication();
		$title = null;

		$title = $this->item->title;

		if ($app->get( 'sitename_pagetitles', 0 ) == 1 ) {
			$title = Text::sprintf( 'JPAGETITLE', $app->get( 'sitename' ), $title );
		} elseif ($app->get( 'sitename_pagetitles', 0 ) == 2 ) {
			$title = Text::sprintf( 'JPAGETITLE', $title, $app->get( 'sitename' ) );
		}
	
		return $title;
    }

	public function getURL() {
        return Uri::root() . Route::_( 'index.php?option=com_allvideoshare&view=video&slg=' . $this->item->slug );	
    }

	public function hasQualitySwitcher() {	
		if ( $this->player->hddock && in_array( $this->item->type, array( 'general', 'url', 'upload' ) ) && ! empty( $this->item->hd ) ) {
			return true;
		}
		
		return false;		
    }

	public function getFileInfo( $url, $format = 'SD' ) {
		$result = array(
			'ext'     => 'mp4',
			'quality' =>  ''
		);

        $parse_url = parse_url( $url );

		// Parse extension
        $ext = pathinfo( $parse_url['path'], PATHINFO_EXTENSION );
        if ( in_array( $ext, array( 'webm', 'ogv' ) ) ) {
			$result['ext'] = $ext;
		}

		// Parse quality
		$filename = pathinfo( $parse_url['path'], PATHINFO_FILENAME );
		$filename = strtolower( $filename );

		$quality_string = '';
		if ( strpos( $filename, '-' ) !== false ) {
			$parts = explode( '-', $filename );
			$quality_string = end( $parts );
		} elseif ( strpos( $filename, '_' ) !== false ) {
			$parts = explode( '_', $filename );
			$quality_string = end( $parts );
		}

		$result['quality'] = (int) $quality_string;
		if ( $quality_string != $result['quality'] . 'p' ) {
			$result['quality'] = ( $format == 'SD' ) ? 480 : 1080;
		};
        
        return $result;        
    }

	public function hasAds() {
        $this->player->ad_engine = ! empty( $this->player->ad_engine ) ? $this->player->ad_engine : 'custom';
		if ( ! $this->canDo ) {
			$this->player->ad_engine = 'custom';
		}

        if ( 'custom' == $this->player->ad_engine ) {
			$lang = Factory::getLanguage();
			$locales = $lang->getLocale();

			if ( $this->player->preroll == 1 || $this->player->postroll == 1 ) {
            	$this->player->vast_url = URI::root() . 'index.php?option=com_allvideoshare&view=ads&type=vmap&id=' . $this->player->id . '&format=xml&lang=' . $locales[4];
				return true;
			}
        } elseif ( 'vast' == $this->player->ad_engine ) {
            if ( ! empty( $this->player->vast_url ) ) {
				$excerpt = $this->item->metadescription;
				if ( empty( $excerpt ) && ! empty( $this->item->description ) ) {
					$excerpt = AllVideoShareHelper::Truncate( $this->item->description );
					$excerpt = str_replace( '...', '', $excerpt );
				}

				$placeholders = array(
					'[domain]'        => URI::root(),
					'[video_id]'      => $this->item->id,
					'[video_title]'   => $this->item->title,
					'[video_excerpt]' => $excerpt,
					'[ip_address]'    =>  $this->getIpAddress()
				);

				$this->player->vast_url = strtr( $this->player->vast_url, $placeholders );
                return true;
            }
        }

        return false;
    }

	public function getIpAddress() {
        // Whether ip is from share internet
        if ( ! empty( $_SERVER['HTTP_CLIENT_IP'] ) ) {
            $ip_address = $_SERVER['HTTP_CLIENT_IP'];
        }
        
        // Whether ip is from proxy
        elseif ( ! empty( $_SERVER['HTTP_X_FORWARDED_FOR'] ) ) {
            $ip_address = $_SERVER['HTTP_X_FORWARDED_FOR'];
        }
        
        // Whether ip is from remote address
        else {
            $ip_address = $_SERVER['REMOTE_ADDR'];
        }
        
        return $ip_address;        
    }

}
